# kubevirt-py
This is KubeVirt API an add-on for Kubernetes.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.7.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen
For more information, please visit [https://github.com/kubevirt/kubevirt](https://github.com/kubevirt/kubevirt)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/d4rkfella/kubevirt-py.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/d4rkfella/kubevirt-py.git`)

Then import the package:
```python
import kubevirt 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import kubevirt
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import kubevirt
from kubevirt.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = kubevirt.DefaultApi(kubevirt.ApiClient(configuration))
body = kubevirt.V1alpha1MigrationPolicy() # V1alpha1MigrationPolicy | 

try:
    api_response = api_instance.create_migration_policy(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->create_migration_policy: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**create_migration_policy**](docs/DefaultApi.md#create_migration_policy) | **POST** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies | 
*DefaultApi* | [**create_namespaced_kube_virt**](docs/DefaultApi.md#create_namespaced_kube_virt) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt | 
*DefaultApi* | [**create_namespaced_virtual_machine**](docs/DefaultApi.md#create_namespaced_virtual_machine) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines | 
*DefaultApi* | [**create_namespaced_virtual_machine_export**](docs/DefaultApi.md#create_namespaced_virtual_machine_export) | **POST** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports | 
*DefaultApi* | [**create_namespaced_virtual_machine_instance**](docs/DefaultApi.md#create_namespaced_virtual_machine_instance) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances | 
*DefaultApi* | [**create_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#create_namespaced_virtual_machine_instance_migration) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations | 
*DefaultApi* | [**create_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#create_namespaced_virtual_machine_instance_preset) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets | 
*DefaultApi* | [**create_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#create_namespaced_virtual_machine_instance_replica_set) | **POST** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets | 
*DefaultApi* | [**create_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#create_namespaced_virtual_machine_instancetype) | **POST** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes | 
*DefaultApi* | [**create_namespaced_virtual_machine_pool**](docs/DefaultApi.md#create_namespaced_virtual_machine_pool) | **POST** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools | 
*DefaultApi* | [**create_namespaced_virtual_machine_preference**](docs/DefaultApi.md#create_namespaced_virtual_machine_preference) | **POST** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences | 
*DefaultApi* | [**create_namespaced_virtual_machine_restore**](docs/DefaultApi.md#create_namespaced_virtual_machine_restore) | **POST** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores | 
*DefaultApi* | [**create_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#create_namespaced_virtual_machine_snapshot) | **POST** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots | 
*DefaultApi* | [**create_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#create_namespaced_virtual_machine_snapshot_content) | **POST** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents | 
*DefaultApi* | [**create_virtual_machine_clone**](docs/DefaultApi.md#create_virtual_machine_clone) | **POST** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones | 
*DefaultApi* | [**create_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#create_virtual_machine_cluster_instancetype) | **POST** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes | 
*DefaultApi* | [**create_virtual_machine_cluster_preference**](docs/DefaultApi.md#create_virtual_machine_cluster_preference) | **POST** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences | 
*DefaultApi* | [**delete_collection_migration_policy**](docs/DefaultApi.md#delete_collection_migration_policy) | **DELETE** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies | 
*DefaultApi* | [**delete_collection_namespaced_kube_virt**](docs/DefaultApi.md#delete_collection_namespaced_kube_virt) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_export**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_export) | **DELETE** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_instance**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_instance) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_instance_migration) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_instance_preset) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_instance_replica_set) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_instancetype) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_pool**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_pool) | **DELETE** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_preference**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_preference) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_restore**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_restore) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_snapshot) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots | 
*DefaultApi* | [**delete_collection_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#delete_collection_namespaced_virtual_machine_snapshot_content) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents | 
*DefaultApi* | [**delete_collection_virtual_machine_clone**](docs/DefaultApi.md#delete_collection_virtual_machine_clone) | **DELETE** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones | 
*DefaultApi* | [**delete_collection_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#delete_collection_virtual_machine_cluster_instancetype) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes | 
*DefaultApi* | [**delete_collection_virtual_machine_cluster_preference**](docs/DefaultApi.md#delete_collection_virtual_machine_cluster_preference) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences | 
*DefaultApi* | [**delete_migration_policy**](docs/DefaultApi.md#delete_migration_policy) | **DELETE** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies/{name} | 
*DefaultApi* | [**delete_namespaced_kube_virt**](docs/DefaultApi.md#delete_namespaced_kube_virt) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine**](docs/DefaultApi.md#delete_namespaced_virtual_machine) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_export**](docs/DefaultApi.md#delete_namespaced_virtual_machine_export) | **DELETE** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_instance**](docs/DefaultApi.md#delete_namespaced_virtual_machine_instance) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#delete_namespaced_virtual_machine_instance_migration) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#delete_namespaced_virtual_machine_instance_preset) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#delete_namespaced_virtual_machine_instance_replica_set) | **DELETE** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#delete_namespaced_virtual_machine_instancetype) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_pool**](docs/DefaultApi.md#delete_namespaced_virtual_machine_pool) | **DELETE** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_preference**](docs/DefaultApi.md#delete_namespaced_virtual_machine_preference) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_restore**](docs/DefaultApi.md#delete_namespaced_virtual_machine_restore) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#delete_namespaced_virtual_machine_snapshot) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots/{name} | 
*DefaultApi* | [**delete_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#delete_namespaced_virtual_machine_snapshot_content) | **DELETE** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents/{name} | 
*DefaultApi* | [**delete_virtual_machine_clone**](docs/DefaultApi.md#delete_virtual_machine_clone) | **DELETE** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones/{name} | 
*DefaultApi* | [**delete_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#delete_virtual_machine_cluster_instancetype) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes/{name} | 
*DefaultApi* | [**delete_virtual_machine_cluster_preference**](docs/DefaultApi.md#delete_virtual_machine_cluster_preference) | **DELETE** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences/{name} | 
*DefaultApi* | [**func15**](docs/DefaultApi.md#func15) | **GET** /healthz | 
*DefaultApi* | [**func6**](docs/DefaultApi.md#func6) | **GET** /openapi/v2 | 
*DefaultApi* | [**get_api_group_clone_kubevirt_io**](docs/DefaultApi.md#get_api_group_clone_kubevirt_io) | **GET** /apis/clone.kubevirt.io/ | 
*DefaultApi* | [**get_api_group_export_kubevirt_io**](docs/DefaultApi.md#get_api_group_export_kubevirt_io) | **GET** /apis/export.kubevirt.io/ | 
*DefaultApi* | [**get_api_group_instancetype_kubevirt_io**](docs/DefaultApi.md#get_api_group_instancetype_kubevirt_io) | **GET** /apis/instancetype.kubevirt.io/ | 
*DefaultApi* | [**get_api_group_kubevirt_io**](docs/DefaultApi.md#get_api_group_kubevirt_io) | **GET** /apis/kubevirt.io/ | 
*DefaultApi* | [**get_api_group_list**](docs/DefaultApi.md#get_api_group_list) | **GET** /apis | 
*DefaultApi* | [**get_api_group_migrations_kubevirt_io**](docs/DefaultApi.md#get_api_group_migrations_kubevirt_io) | **GET** /apis/migrations.kubevirt.io/ | 
*DefaultApi* | [**get_api_group_pool_kubevirt_io**](docs/DefaultApi.md#get_api_group_pool_kubevirt_io) | **GET** /apis/pool.kubevirt.io/ | 
*DefaultApi* | [**get_api_group_snapshot_kubevirt_io**](docs/DefaultApi.md#get_api_group_snapshot_kubevirt_io) | **GET** /apis/snapshot.kubevirt.io/ | 
*DefaultApi* | [**get_api_resources_clone_kubevirt_io_v1beta1**](docs/DefaultApi.md#get_api_resources_clone_kubevirt_io_v1beta1) | **GET** /apis/clone.kubevirt.io/v1beta1/ | 
*DefaultApi* | [**get_api_resources_export_kubevirt_io_v1beta1**](docs/DefaultApi.md#get_api_resources_export_kubevirt_io_v1beta1) | **GET** /apis/export.kubevirt.io/v1beta1/ | 
*DefaultApi* | [**get_api_resources_instancetype_kubevirt_io_v1beta1**](docs/DefaultApi.md#get_api_resources_instancetype_kubevirt_io_v1beta1) | **GET** /apis/instancetype.kubevirt.io/v1beta1/ | 
*DefaultApi* | [**get_api_resources_kubevirt_io_v1**](docs/DefaultApi.md#get_api_resources_kubevirt_io_v1) | **GET** /apis/kubevirt.io/v1/ | 
*DefaultApi* | [**get_api_resources_migrations_kubevirt_io_v1alpha1**](docs/DefaultApi.md#get_api_resources_migrations_kubevirt_io_v1alpha1) | **GET** /apis/migrations.kubevirt.io/v1alpha1/ | 
*DefaultApi* | [**get_api_resources_pool_kubevirt_io_v1beta1**](docs/DefaultApi.md#get_api_resources_pool_kubevirt_io_v1beta1) | **GET** /apis/pool.kubevirt.io/v1beta1/ | 
*DefaultApi* | [**get_api_resources_snapshot_kubevirt_io_v1beta1**](docs/DefaultApi.md#get_api_resources_snapshot_kubevirt_io_v1beta1) | **GET** /apis/snapshot.kubevirt.io/v1beta1/ | 
*DefaultApi* | [**get_root_paths**](docs/DefaultApi.md#get_root_paths) | **GET** / | 
*DefaultApi* | [**handle_dump_profiler**](docs/DefaultApi.md#handle_dump_profiler) | **GET** /dump-profiler | 
*DefaultApi* | [**handle_start_profiler**](docs/DefaultApi.md#handle_start_profiler) | **GET** /start-profiler | 
*DefaultApi* | [**handle_stop_profiler**](docs/DefaultApi.md#handle_stop_profiler) | **GET** /stop-profiler | 
*DefaultApi* | [**list_kube_virt_for_all_namespaces**](docs/DefaultApi.md#list_kube_virt_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/kubevirt | 
*DefaultApi* | [**list_migration_policy**](docs/DefaultApi.md#list_migration_policy) | **GET** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies | 
*DefaultApi* | [**list_namespaced_kube_virt**](docs/DefaultApi.md#list_namespaced_kube_virt) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt | 
*DefaultApi* | [**list_namespaced_virtual_machine**](docs/DefaultApi.md#list_namespaced_virtual_machine) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines | 
*DefaultApi* | [**list_namespaced_virtual_machine_export**](docs/DefaultApi.md#list_namespaced_virtual_machine_export) | **GET** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports | 
*DefaultApi* | [**list_namespaced_virtual_machine_instance**](docs/DefaultApi.md#list_namespaced_virtual_machine_instance) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances | 
*DefaultApi* | [**list_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#list_namespaced_virtual_machine_instance_migration) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations | 
*DefaultApi* | [**list_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#list_namespaced_virtual_machine_instance_preset) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets | 
*DefaultApi* | [**list_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#list_namespaced_virtual_machine_instance_replica_set) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets | 
*DefaultApi* | [**list_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#list_namespaced_virtual_machine_instancetype) | **GET** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes | 
*DefaultApi* | [**list_namespaced_virtual_machine_pool**](docs/DefaultApi.md#list_namespaced_virtual_machine_pool) | **GET** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools | 
*DefaultApi* | [**list_namespaced_virtual_machine_preference**](docs/DefaultApi.md#list_namespaced_virtual_machine_preference) | **GET** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences | 
*DefaultApi* | [**list_namespaced_virtual_machine_restore**](docs/DefaultApi.md#list_namespaced_virtual_machine_restore) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores | 
*DefaultApi* | [**list_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#list_namespaced_virtual_machine_snapshot) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots | 
*DefaultApi* | [**list_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#list_namespaced_virtual_machine_snapshot_content) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents | 
*DefaultApi* | [**list_virtual_machine_clone**](docs/DefaultApi.md#list_virtual_machine_clone) | **GET** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones | 
*DefaultApi* | [**list_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#list_virtual_machine_cluster_instancetype) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes | 
*DefaultApi* | [**list_virtual_machine_cluster_preference**](docs/DefaultApi.md#list_virtual_machine_cluster_preference) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences | 
*DefaultApi* | [**list_virtual_machine_export_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_export_for_all_namespaces) | **GET** /apis/export.kubevirt.io/v1beta1/virtualmachineexports | 
*DefaultApi* | [**list_virtual_machine_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/virtualmachines | 
*DefaultApi* | [**list_virtual_machine_instance_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_instance_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/virtualmachineinstances | 
*DefaultApi* | [**list_virtual_machine_instance_migration_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_instance_migration_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/virtualmachineinstancemigrations | 
*DefaultApi* | [**list_virtual_machine_instance_preset_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_instance_preset_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/virtualmachineinstancepresets | 
*DefaultApi* | [**list_virtual_machine_instance_replica_set_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_instance_replica_set_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/virtualmachineinstancereplicasets | 
*DefaultApi* | [**list_virtual_machine_instancetype_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_instancetype_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineinstancetypes | 
*DefaultApi* | [**list_virtual_machine_pool_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_pool_for_all_namespaces) | **GET** /apis/pool.kubevirt.io/v1beta1/virtualmachinepools | 
*DefaultApi* | [**list_virtual_machine_preference_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_preference_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachinepreferences | 
*DefaultApi* | [**list_virtual_machine_restore_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_restore_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/virtualmachinerestores | 
*DefaultApi* | [**list_virtual_machine_snapshot_content_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_snapshot_content_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/virtualmachinesnapshotcontents | 
*DefaultApi* | [**list_virtual_machine_snapshot_for_all_namespaces**](docs/DefaultApi.md#list_virtual_machine_snapshot_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/virtualmachinesnapshots | 
*DefaultApi* | [**patch_migration_policy**](docs/DefaultApi.md#patch_migration_policy) | **PATCH** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies/{name} | 
*DefaultApi* | [**patch_namespaced_kube_virt**](docs/DefaultApi.md#patch_namespaced_kube_virt) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine**](docs/DefaultApi.md#patch_namespaced_virtual_machine) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_export**](docs/DefaultApi.md#patch_namespaced_virtual_machine_export) | **PATCH** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_instance**](docs/DefaultApi.md#patch_namespaced_virtual_machine_instance) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#patch_namespaced_virtual_machine_instance_migration) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#patch_namespaced_virtual_machine_instance_preset) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#patch_namespaced_virtual_machine_instance_replica_set) | **PATCH** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#patch_namespaced_virtual_machine_instancetype) | **PATCH** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_pool**](docs/DefaultApi.md#patch_namespaced_virtual_machine_pool) | **PATCH** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_preference**](docs/DefaultApi.md#patch_namespaced_virtual_machine_preference) | **PATCH** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_restore**](docs/DefaultApi.md#patch_namespaced_virtual_machine_restore) | **PATCH** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#patch_namespaced_virtual_machine_snapshot) | **PATCH** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots/{name} | 
*DefaultApi* | [**patch_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#patch_namespaced_virtual_machine_snapshot_content) | **PATCH** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents/{name} | 
*DefaultApi* | [**patch_virtual_machine_clone**](docs/DefaultApi.md#patch_virtual_machine_clone) | **PATCH** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones/{name} | 
*DefaultApi* | [**patch_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#patch_virtual_machine_cluster_instancetype) | **PATCH** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes/{name} | 
*DefaultApi* | [**patch_virtual_machine_cluster_preference**](docs/DefaultApi.md#patch_virtual_machine_cluster_preference) | **PATCH** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences/{name} | 
*DefaultApi* | [**read_migration_policy**](docs/DefaultApi.md#read_migration_policy) | **GET** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies/{name} | 
*DefaultApi* | [**read_namespaced_kube_virt**](docs/DefaultApi.md#read_namespaced_kube_virt) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine**](docs/DefaultApi.md#read_namespaced_virtual_machine) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_export**](docs/DefaultApi.md#read_namespaced_virtual_machine_export) | **GET** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_instance**](docs/DefaultApi.md#read_namespaced_virtual_machine_instance) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#read_namespaced_virtual_machine_instance_migration) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#read_namespaced_virtual_machine_instance_preset) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#read_namespaced_virtual_machine_instance_replica_set) | **GET** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#read_namespaced_virtual_machine_instancetype) | **GET** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_pool**](docs/DefaultApi.md#read_namespaced_virtual_machine_pool) | **GET** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_preference**](docs/DefaultApi.md#read_namespaced_virtual_machine_preference) | **GET** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_restore**](docs/DefaultApi.md#read_namespaced_virtual_machine_restore) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#read_namespaced_virtual_machine_snapshot) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots/{name} | 
*DefaultApi* | [**read_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#read_namespaced_virtual_machine_snapshot_content) | **GET** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents/{name} | 
*DefaultApi* | [**read_virtual_machine_clone**](docs/DefaultApi.md#read_virtual_machine_clone) | **GET** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones/{name} | 
*DefaultApi* | [**read_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#read_virtual_machine_cluster_instancetype) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes/{name} | 
*DefaultApi* | [**read_virtual_machine_cluster_preference**](docs/DefaultApi.md#read_virtual_machine_cluster_preference) | **GET** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences/{name} | 
*DefaultApi* | [**replace_migration_policy**](docs/DefaultApi.md#replace_migration_policy) | **PUT** /apis/migrations.kubevirt.io/v1alpha1/migrationpolicies/{name} | 
*DefaultApi* | [**replace_namespaced_kube_virt**](docs/DefaultApi.md#replace_namespaced_kube_virt) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/kubevirt/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine**](docs/DefaultApi.md#replace_namespaced_virtual_machine) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_export**](docs/DefaultApi.md#replace_namespaced_virtual_machine_export) | **PUT** /apis/export.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineexports/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_instance**](docs/DefaultApi.md#replace_namespaced_virtual_machine_instance) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#replace_namespaced_virtual_machine_instance_migration) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancemigrations/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#replace_namespaced_virtual_machine_instance_preset) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancepresets/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#replace_namespaced_virtual_machine_instance_replica_set) | **PUT** /apis/kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstancereplicasets/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#replace_namespaced_virtual_machine_instancetype) | **PUT** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachineinstancetypes/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_pool**](docs/DefaultApi.md#replace_namespaced_virtual_machine_pool) | **PUT** /apis/pool.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepools/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_preference**](docs/DefaultApi.md#replace_namespaced_virtual_machine_preference) | **PUT** /apis/instancetype.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinepreferences/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_restore**](docs/DefaultApi.md#replace_namespaced_virtual_machine_restore) | **PUT** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinerestores/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#replace_namespaced_virtual_machine_snapshot) | **PUT** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshots/{name} | 
*DefaultApi* | [**replace_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#replace_namespaced_virtual_machine_snapshot_content) | **PUT** /apis/snapshot.kubevirt.io/v1beta1/namespaces/{namespace}/virtualmachinesnapshotcontents/{name} | 
*DefaultApi* | [**replace_virtual_machine_clone**](docs/DefaultApi.md#replace_virtual_machine_clone) | **PUT** /apis/clone.kubevirt.io/v1beta1/virtualmachineclones/{name} | 
*DefaultApi* | [**replace_virtual_machine_cluster_instancetype**](docs/DefaultApi.md#replace_virtual_machine_cluster_instancetype) | **PUT** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterinstancetypes/{name} | 
*DefaultApi* | [**replace_virtual_machine_cluster_preference**](docs/DefaultApi.md#replace_virtual_machine_cluster_preference) | **PUT** /apis/instancetype.kubevirt.io/v1beta1/virtualmachineclusterpreferences/{name} | 
*DefaultApi* | [**v1_check_health**](docs/DefaultApi.md#v1_check_health) | **GET** /apis/subresources.kubevirt.io/v1/healthz | 
*DefaultApi* | [**v1_console**](docs/DefaultApi.md#v1_console) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/console | 
*DefaultApi* | [**v1_expand_spec**](docs/DefaultApi.md#v1_expand_spec) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/expand-vm-spec | 
*DefaultApi* | [**v1_filesystemlist**](docs/DefaultApi.md#v1_filesystemlist) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/filesystemlist | 
*DefaultApi* | [**v1_freeze**](docs/DefaultApi.md#v1_freeze) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/freeze | 
*DefaultApi* | [**v1_get_sub_api_group**](docs/DefaultApi.md#v1_get_sub_api_group) | **GET** /apis/subresources.kubevirt.io | 
*DefaultApi* | [**v1_guestfs**](docs/DefaultApi.md#v1_guestfs) | **GET** /apis/subresources.kubevirt.io/v1/guestfs | 
*DefaultApi* | [**v1_guestosinfo**](docs/DefaultApi.md#v1_guestosinfo) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/guestosinfo | 
*DefaultApi* | [**v1_memory_dump**](docs/DefaultApi.md#v1_memory_dump) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/memorydump | 
*DefaultApi* | [**v1_migrate**](docs/DefaultApi.md#v1_migrate) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/migrate | 
*DefaultApi* | [**v1_pause**](docs/DefaultApi.md#v1_pause) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/pause | 
*DefaultApi* | [**v1_remove_memory_dump**](docs/DefaultApi.md#v1_remove_memory_dump) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/removememorydump | 
*DefaultApi* | [**v1_reset**](docs/DefaultApi.md#v1_reset) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/reset | 
*DefaultApi* | [**v1_restart**](docs/DefaultApi.md#v1_restart) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/restart | 
*DefaultApi* | [**v1_sev_fetch_cert_chain**](docs/DefaultApi.md#v1_sev_fetch_cert_chain) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/sev/fetchcertchain | 
*DefaultApi* | [**v1_sev_inject_launch_secret**](docs/DefaultApi.md#v1_sev_inject_launch_secret) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/sev/injectlaunchsecret | 
*DefaultApi* | [**v1_sev_query_launch_measurement**](docs/DefaultApi.md#v1_sev_query_launch_measurement) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/sev/querylaunchmeasurement | 
*DefaultApi* | [**v1_sev_setup_session**](docs/DefaultApi.md#v1_sev_setup_session) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/sev/setupsession | 
*DefaultApi* | [**v1_soft_reboot**](docs/DefaultApi.md#v1_soft_reboot) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/softreboot | 
*DefaultApi* | [**v1_start**](docs/DefaultApi.md#v1_start) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/start | 
*DefaultApi* | [**v1_stop**](docs/DefaultApi.md#v1_stop) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/stop | 
*DefaultApi* | [**v1_unfreeze**](docs/DefaultApi.md#v1_unfreeze) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/unfreeze | 
*DefaultApi* | [**v1_unpause**](docs/DefaultApi.md#v1_unpause) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/unpause | 
*DefaultApi* | [**v1_userlist**](docs/DefaultApi.md#v1_userlist) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/userlist | 
*DefaultApi* | [**v1_version**](docs/DefaultApi.md#v1_version) | **GET** /apis/subresources.kubevirt.io/v1/version | 
*DefaultApi* | [**v1_vnc**](docs/DefaultApi.md#v1_vnc) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/vnc | 
*DefaultApi* | [**v1_vnc_screenshot**](docs/DefaultApi.md#v1_vnc_screenshot) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/vnc/screenshot | 
*DefaultApi* | [**v1_vsock**](docs/DefaultApi.md#v1_vsock) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/vsock | 
*DefaultApi* | [**v1alpha3_check_health**](docs/DefaultApi.md#v1alpha3_check_health) | **GET** /apis/subresources.kubevirt.io/v1alpha3/healthz | 
*DefaultApi* | [**v1alpha3_console**](docs/DefaultApi.md#v1alpha3_console) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/console | 
*DefaultApi* | [**v1alpha3_expand_spec**](docs/DefaultApi.md#v1alpha3_expand_spec) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/expand-vm-spec | 
*DefaultApi* | [**v1alpha3_filesystemlist**](docs/DefaultApi.md#v1alpha3_filesystemlist) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/filesystemlist | 
*DefaultApi* | [**v1alpha3_freeze**](docs/DefaultApi.md#v1alpha3_freeze) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/freeze | 
*DefaultApi* | [**v1alpha3_guestfs**](docs/DefaultApi.md#v1alpha3_guestfs) | **GET** /apis/subresources.kubevirt.io/v1alpha3/guestfs | 
*DefaultApi* | [**v1alpha3_guestosinfo**](docs/DefaultApi.md#v1alpha3_guestosinfo) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/guestosinfo | 
*DefaultApi* | [**v1alpha3_memory_dump**](docs/DefaultApi.md#v1alpha3_memory_dump) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/memorydump | 
*DefaultApi* | [**v1alpha3_migrate**](docs/DefaultApi.md#v1alpha3_migrate) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/migrate | 
*DefaultApi* | [**v1alpha3_pause**](docs/DefaultApi.md#v1alpha3_pause) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/pause | 
*DefaultApi* | [**v1alpha3_remove_memory_dump**](docs/DefaultApi.md#v1alpha3_remove_memory_dump) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/removememorydump | 
*DefaultApi* | [**v1alpha3_reset**](docs/DefaultApi.md#v1alpha3_reset) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/reset | 
*DefaultApi* | [**v1alpha3_restart**](docs/DefaultApi.md#v1alpha3_restart) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/restart | 
*DefaultApi* | [**v1alpha3_sev_fetch_cert_chain**](docs/DefaultApi.md#v1alpha3_sev_fetch_cert_chain) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/sev/fetchcertchain | 
*DefaultApi* | [**v1alpha3_sev_inject_launch_secret**](docs/DefaultApi.md#v1alpha3_sev_inject_launch_secret) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/sev/injectlaunchsecret | 
*DefaultApi* | [**v1alpha3_sev_query_launch_measurement**](docs/DefaultApi.md#v1alpha3_sev_query_launch_measurement) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/sev/querylaunchmeasurement | 
*DefaultApi* | [**v1alpha3_sev_setup_session**](docs/DefaultApi.md#v1alpha3_sev_setup_session) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/sev/setupsession | 
*DefaultApi* | [**v1alpha3_soft_reboot**](docs/DefaultApi.md#v1alpha3_soft_reboot) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/softreboot | 
*DefaultApi* | [**v1alpha3_start**](docs/DefaultApi.md#v1alpha3_start) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/start | 
*DefaultApi* | [**v1alpha3_stop**](docs/DefaultApi.md#v1alpha3_stop) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/stop | 
*DefaultApi* | [**v1alpha3_unfreeze**](docs/DefaultApi.md#v1alpha3_unfreeze) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/unfreeze | 
*DefaultApi* | [**v1alpha3_unpause**](docs/DefaultApi.md#v1alpha3_unpause) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/unpause | 
*DefaultApi* | [**v1alpha3_userlist**](docs/DefaultApi.md#v1alpha3_userlist) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/userlist | 
*DefaultApi* | [**v1alpha3_version**](docs/DefaultApi.md#v1alpha3_version) | **GET** /apis/subresources.kubevirt.io/v1alpha3/version | 
*DefaultApi* | [**v1alpha3_vnc**](docs/DefaultApi.md#v1alpha3_vnc) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/vnc | 
*DefaultApi* | [**v1alpha3_vnc_screenshot**](docs/DefaultApi.md#v1alpha3_vnc_screenshot) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/vnc/screenshot | 
*DefaultApi* | [**v1alpha3_vsock**](docs/DefaultApi.md#v1alpha3_vsock) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/vsock | 
*DefaultApi* | [**v1alpha3dump_cluster_profiler**](docs/DefaultApi.md#v1alpha3dump_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1alpha3/dump-cluster-profiler | 
*DefaultApi* | [**v1alpha3get_api_sub_resources**](docs/DefaultApi.md#v1alpha3get_api_sub_resources) | **GET** /apis/subresources.kubevirt.io/v1alpha3/ | 
*DefaultApi* | [**v1alpha3start_cluster_profiler**](docs/DefaultApi.md#v1alpha3start_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1alpha3/start-cluster-profiler | 
*DefaultApi* | [**v1alpha3stop_cluster_profiler**](docs/DefaultApi.md#v1alpha3stop_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1alpha3/stop-cluster-profiler | 
*DefaultApi* | [**v1alpha3usbredir**](docs/DefaultApi.md#v1alpha3usbredir) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/usbredir | 
*DefaultApi* | [**v1alpha3vm_addvolume**](docs/DefaultApi.md#v1alpha3vm_addvolume) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/addvolume | 
*DefaultApi* | [**v1alpha3vm_evacuatecancel**](docs/DefaultApi.md#v1alpha3vm_evacuatecancel) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/evacuate/cancel | 
*DefaultApi* | [**v1alpha3vm_expand_spec**](docs/DefaultApi.md#v1alpha3vm_expand_spec) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/expand-spec | 
*DefaultApi* | [**v1alpha3vm_objectgraph**](docs/DefaultApi.md#v1alpha3vm_objectgraph) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/objectgraph | 
*DefaultApi* | [**v1alpha3vm_port_forward**](docs/DefaultApi.md#v1alpha3vm_port_forward) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/portforward/{port} | 
*DefaultApi* | [**v1alpha3vm_port_forward_with_protocol**](docs/DefaultApi.md#v1alpha3vm_port_forward_with_protocol) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/portforward/{port}/{protocol} | 
*DefaultApi* | [**v1alpha3vm_removevolume**](docs/DefaultApi.md#v1alpha3vm_removevolume) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachines/{name}/removevolume | 
*DefaultApi* | [**v1alpha3vmi_addvolume**](docs/DefaultApi.md#v1alpha3vmi_addvolume) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/addvolume | 
*DefaultApi* | [**v1alpha3vmi_evacuatecancel**](docs/DefaultApi.md#v1alpha3vmi_evacuatecancel) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/evacuate/cancel | 
*DefaultApi* | [**v1alpha3vmi_objectgraph**](docs/DefaultApi.md#v1alpha3vmi_objectgraph) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/objectgraph | 
*DefaultApi* | [**v1alpha3vmi_port_forward**](docs/DefaultApi.md#v1alpha3vmi_port_forward) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/portforward/{port} | 
*DefaultApi* | [**v1alpha3vmi_port_forward_with_protocol**](docs/DefaultApi.md#v1alpha3vmi_port_forward_with_protocol) | **GET** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/portforward/{port}/{protocol} | 
*DefaultApi* | [**v1alpha3vmi_removevolume**](docs/DefaultApi.md#v1alpha3vmi_removevolume) | **PUT** /apis/subresources.kubevirt.io/v1alpha3/namespaces/{namespace}/virtualmachineinstances/{name}/removevolume | 
*DefaultApi* | [**v1dump_cluster_profiler**](docs/DefaultApi.md#v1dump_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1/dump-cluster-profiler | 
*DefaultApi* | [**v1get_api_sub_resources**](docs/DefaultApi.md#v1get_api_sub_resources) | **GET** /apis/subresources.kubevirt.io/v1/ | 
*DefaultApi* | [**v1start_cluster_profiler**](docs/DefaultApi.md#v1start_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1/start-cluster-profiler | 
*DefaultApi* | [**v1stop_cluster_profiler**](docs/DefaultApi.md#v1stop_cluster_profiler) | **GET** /apis/subresources.kubevirt.io/v1/stop-cluster-profiler | 
*DefaultApi* | [**v1usbredir**](docs/DefaultApi.md#v1usbredir) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/usbredir | 
*DefaultApi* | [**v1vm_addvolume**](docs/DefaultApi.md#v1vm_addvolume) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/addvolume | 
*DefaultApi* | [**v1vm_evacuatecancel**](docs/DefaultApi.md#v1vm_evacuatecancel) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/evacuate/cancel | 
*DefaultApi* | [**v1vm_expand_spec**](docs/DefaultApi.md#v1vm_expand_spec) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/expand-spec | 
*DefaultApi* | [**v1vm_objectgraph**](docs/DefaultApi.md#v1vm_objectgraph) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/objectgraph | 
*DefaultApi* | [**v1vm_port_forward**](docs/DefaultApi.md#v1vm_port_forward) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/portforward/{port} | 
*DefaultApi* | [**v1vm_port_forward_with_protocol**](docs/DefaultApi.md#v1vm_port_forward_with_protocol) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/portforward/{port}/{protocol} | 
*DefaultApi* | [**v1vm_removevolume**](docs/DefaultApi.md#v1vm_removevolume) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachines/{name}/removevolume | 
*DefaultApi* | [**v1vmi_addvolume**](docs/DefaultApi.md#v1vmi_addvolume) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/addvolume | 
*DefaultApi* | [**v1vmi_evacuatecancel**](docs/DefaultApi.md#v1vmi_evacuatecancel) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/evacuate/cancel | 
*DefaultApi* | [**v1vmi_objectgraph**](docs/DefaultApi.md#v1vmi_objectgraph) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/objectgraph | 
*DefaultApi* | [**v1vmi_port_forward**](docs/DefaultApi.md#v1vmi_port_forward) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/portforward/{port} | 
*DefaultApi* | [**v1vmi_port_forward_with_protocol**](docs/DefaultApi.md#v1vmi_port_forward_with_protocol) | **GET** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/portforward/{port}/{protocol} | 
*DefaultApi* | [**v1vmi_removevolume**](docs/DefaultApi.md#v1vmi_removevolume) | **PUT** /apis/subresources.kubevirt.io/v1/namespaces/{namespace}/virtualmachineinstances/{name}/removevolume | 
*DefaultApi* | [**watch_kube_virt_list_for_all_namespaces**](docs/DefaultApi.md#watch_kube_virt_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/kubevirt | 
*DefaultApi* | [**watch_migration_policy_list_for_all_namespaces**](docs/DefaultApi.md#watch_migration_policy_list_for_all_namespaces) | **GET** /apis/migrations.kubevirt.io/v1alpha1/watch/migrationpolicies | 
*DefaultApi* | [**watch_namespaced_kube_virt**](docs/DefaultApi.md#watch_namespaced_kube_virt) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/kubevirt | 
*DefaultApi* | [**watch_namespaced_virtual_machine**](docs/DefaultApi.md#watch_namespaced_virtual_machine) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/virtualmachines | 
*DefaultApi* | [**watch_namespaced_virtual_machine_export**](docs/DefaultApi.md#watch_namespaced_virtual_machine_export) | **GET** /apis/export.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachineexports | 
*DefaultApi* | [**watch_namespaced_virtual_machine_instance**](docs/DefaultApi.md#watch_namespaced_virtual_machine_instance) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/virtualmachineinstances | 
*DefaultApi* | [**watch_namespaced_virtual_machine_instance_migration**](docs/DefaultApi.md#watch_namespaced_virtual_machine_instance_migration) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/virtualmachineinstancemigrations | 
*DefaultApi* | [**watch_namespaced_virtual_machine_instance_preset**](docs/DefaultApi.md#watch_namespaced_virtual_machine_instance_preset) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/virtualmachineinstancepresets | 
*DefaultApi* | [**watch_namespaced_virtual_machine_instance_replica_set**](docs/DefaultApi.md#watch_namespaced_virtual_machine_instance_replica_set) | **GET** /apis/kubevirt.io/v1/watch/namespaces/{namespace}/virtualmachineinstancereplicasets | 
*DefaultApi* | [**watch_namespaced_virtual_machine_instancetype**](docs/DefaultApi.md#watch_namespaced_virtual_machine_instancetype) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachineinstancetypes | 
*DefaultApi* | [**watch_namespaced_virtual_machine_pool**](docs/DefaultApi.md#watch_namespaced_virtual_machine_pool) | **GET** /apis/pool.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachinepools | 
*DefaultApi* | [**watch_namespaced_virtual_machine_preference**](docs/DefaultApi.md#watch_namespaced_virtual_machine_preference) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachinepreferences | 
*DefaultApi* | [**watch_namespaced_virtual_machine_restore**](docs/DefaultApi.md#watch_namespaced_virtual_machine_restore) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachinerestores | 
*DefaultApi* | [**watch_namespaced_virtual_machine_snapshot**](docs/DefaultApi.md#watch_namespaced_virtual_machine_snapshot) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachinesnapshots | 
*DefaultApi* | [**watch_namespaced_virtual_machine_snapshot_content**](docs/DefaultApi.md#watch_namespaced_virtual_machine_snapshot_content) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/namespaces/{namespace}/virtualmachinesnapshotcontents | 
*DefaultApi* | [**watch_virtual_machine_clone_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_clone_list_for_all_namespaces) | **GET** /apis/clone.kubevirt.io/v1beta1/watch/virtualmachineclones | 
*DefaultApi* | [**watch_virtual_machine_cluster_instancetype_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_cluster_instancetype_list_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/virtualmachineclusterinstancetypes | 
*DefaultApi* | [**watch_virtual_machine_cluster_preference_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_cluster_preference_list_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/virtualmachineclusterpreferences | 
*DefaultApi* | [**watch_virtual_machine_export_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_export_list_for_all_namespaces) | **GET** /apis/export.kubevirt.io/v1beta1/watch/virtualmachineexports | 
*DefaultApi* | [**watch_virtual_machine_instance_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_instance_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/virtualmachineinstances | 
*DefaultApi* | [**watch_virtual_machine_instance_migration_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_instance_migration_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/virtualmachineinstancemigrations | 
*DefaultApi* | [**watch_virtual_machine_instance_preset_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_instance_preset_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/virtualmachineinstancepresets | 
*DefaultApi* | [**watch_virtual_machine_instance_replica_set_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_instance_replica_set_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/virtualmachineinstancereplicasets | 
*DefaultApi* | [**watch_virtual_machine_instancetype_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_instancetype_list_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/virtualmachineinstancetypes | 
*DefaultApi* | [**watch_virtual_machine_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_list_for_all_namespaces) | **GET** /apis/kubevirt.io/v1/watch/virtualmachines | 
*DefaultApi* | [**watch_virtual_machine_pool_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_pool_list_for_all_namespaces) | **GET** /apis/pool.kubevirt.io/v1beta1/watch/virtualmachinepools | 
*DefaultApi* | [**watch_virtual_machine_preference_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_preference_list_for_all_namespaces) | **GET** /apis/instancetype.kubevirt.io/v1beta1/watch/virtualmachinepreferences | 
*DefaultApi* | [**watch_virtual_machine_restore_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_restore_list_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/virtualmachinerestores | 
*DefaultApi* | [**watch_virtual_machine_snapshot_content_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_snapshot_content_list_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/virtualmachinesnapshotcontents | 
*DefaultApi* | [**watch_virtual_machine_snapshot_list_for_all_namespaces**](docs/DefaultApi.md#watch_virtual_machine_snapshot_list_for_all_namespaces) | **GET** /apis/snapshot.kubevirt.io/v1beta1/watch/virtualmachinesnapshots | 


## Documentation For Models

 - [K8sIoApiCoreV1Affinity](docs/K8sIoApiCoreV1Affinity.md)
 - [K8sIoApiCoreV1DownwardAPIVolumeFile](docs/K8sIoApiCoreV1DownwardAPIVolumeFile.md)
 - [K8sIoApiCoreV1ExecAction](docs/K8sIoApiCoreV1ExecAction.md)
 - [K8sIoApiCoreV1HTTPGetAction](docs/K8sIoApiCoreV1HTTPGetAction.md)
 - [K8sIoApiCoreV1HTTPHeader](docs/K8sIoApiCoreV1HTTPHeader.md)
 - [K8sIoApiCoreV1LocalObjectReference](docs/K8sIoApiCoreV1LocalObjectReference.md)
 - [K8sIoApiCoreV1NodeAffinity](docs/K8sIoApiCoreV1NodeAffinity.md)
 - [K8sIoApiCoreV1NodeSelector](docs/K8sIoApiCoreV1NodeSelector.md)
 - [K8sIoApiCoreV1NodeSelectorRequirement](docs/K8sIoApiCoreV1NodeSelectorRequirement.md)
 - [K8sIoApiCoreV1NodeSelectorTerm](docs/K8sIoApiCoreV1NodeSelectorTerm.md)
 - [K8sIoApiCoreV1ObjectFieldSelector](docs/K8sIoApiCoreV1ObjectFieldSelector.md)
 - [K8sIoApiCoreV1PersistentVolumeClaimSpec](docs/K8sIoApiCoreV1PersistentVolumeClaimSpec.md)
 - [K8sIoApiCoreV1PersistentVolumeClaimVolumeSource](docs/K8sIoApiCoreV1PersistentVolumeClaimVolumeSource.md)
 - [K8sIoApiCoreV1PodAffinity](docs/K8sIoApiCoreV1PodAffinity.md)
 - [K8sIoApiCoreV1PodAffinityTerm](docs/K8sIoApiCoreV1PodAffinityTerm.md)
 - [K8sIoApiCoreV1PodAntiAffinity](docs/K8sIoApiCoreV1PodAntiAffinity.md)
 - [K8sIoApiCoreV1PodDNSConfig](docs/K8sIoApiCoreV1PodDNSConfig.md)
 - [K8sIoApiCoreV1PodDNSConfigOption](docs/K8sIoApiCoreV1PodDNSConfigOption.md)
 - [K8sIoApiCoreV1PodResourceClaim](docs/K8sIoApiCoreV1PodResourceClaim.md)
 - [K8sIoApiCoreV1PreferredSchedulingTerm](docs/K8sIoApiCoreV1PreferredSchedulingTerm.md)
 - [K8sIoApiCoreV1ResourceFieldSelector](docs/K8sIoApiCoreV1ResourceFieldSelector.md)
 - [K8sIoApiCoreV1TCPSocketAction](docs/K8sIoApiCoreV1TCPSocketAction.md)
 - [K8sIoApiCoreV1Toleration](docs/K8sIoApiCoreV1Toleration.md)
 - [K8sIoApiCoreV1TopologySpreadConstraint](docs/K8sIoApiCoreV1TopologySpreadConstraint.md)
 - [K8sIoApiCoreV1TypedLocalObjectReference](docs/K8sIoApiCoreV1TypedLocalObjectReference.md)
 - [K8sIoApiCoreV1TypedObjectReference](docs/K8sIoApiCoreV1TypedObjectReference.md)
 - [K8sIoApiCoreV1VolumeResourceRequirements](docs/K8sIoApiCoreV1VolumeResourceRequirements.md)
 - [K8sIoApiCoreV1WeightedPodAffinityTerm](docs/K8sIoApiCoreV1WeightedPodAffinityTerm.md)
 - [K8sIoApimachineryPkgApiResourceQuantity](docs/K8sIoApimachineryPkgApiResourceQuantity.md)
 - [K8sIoApimachineryPkgApisMetaV1APIGroup](docs/K8sIoApimachineryPkgApisMetaV1APIGroup.md)
 - [K8sIoApimachineryPkgApisMetaV1APIGroupList](docs/K8sIoApimachineryPkgApisMetaV1APIGroupList.md)
 - [K8sIoApimachineryPkgApisMetaV1APIResource](docs/K8sIoApimachineryPkgApisMetaV1APIResource.md)
 - [K8sIoApimachineryPkgApisMetaV1APIResourceList](docs/K8sIoApimachineryPkgApisMetaV1APIResourceList.md)
 - [K8sIoApimachineryPkgApisMetaV1DeleteOptions](docs/K8sIoApimachineryPkgApisMetaV1DeleteOptions.md)
 - [K8sIoApimachineryPkgApisMetaV1Duration](docs/K8sIoApimachineryPkgApisMetaV1Duration.md)
 - [K8sIoApimachineryPkgApisMetaV1FieldsV1](docs/K8sIoApimachineryPkgApisMetaV1FieldsV1.md)
 - [K8sIoApimachineryPkgApisMetaV1GroupVersionForDiscovery](docs/K8sIoApimachineryPkgApisMetaV1GroupVersionForDiscovery.md)
 - [K8sIoApimachineryPkgApisMetaV1LabelSelector](docs/K8sIoApimachineryPkgApisMetaV1LabelSelector.md)
 - [K8sIoApimachineryPkgApisMetaV1LabelSelectorRequirement](docs/K8sIoApimachineryPkgApisMetaV1LabelSelectorRequirement.md)
 - [K8sIoApimachineryPkgApisMetaV1ListMeta](docs/K8sIoApimachineryPkgApisMetaV1ListMeta.md)
 - [K8sIoApimachineryPkgApisMetaV1ManagedFieldsEntry](docs/K8sIoApimachineryPkgApisMetaV1ManagedFieldsEntry.md)
 - [K8sIoApimachineryPkgApisMetaV1ObjectMeta](docs/K8sIoApimachineryPkgApisMetaV1ObjectMeta.md)
 - [K8sIoApimachineryPkgApisMetaV1OwnerReference](docs/K8sIoApimachineryPkgApisMetaV1OwnerReference.md)
 - [K8sIoApimachineryPkgApisMetaV1Patch](docs/K8sIoApimachineryPkgApisMetaV1Patch.md)
 - [K8sIoApimachineryPkgApisMetaV1Preconditions](docs/K8sIoApimachineryPkgApisMetaV1Preconditions.md)
 - [K8sIoApimachineryPkgApisMetaV1RootPaths](docs/K8sIoApimachineryPkgApisMetaV1RootPaths.md)
 - [K8sIoApimachineryPkgApisMetaV1ServerAddressByClientCIDR](docs/K8sIoApimachineryPkgApisMetaV1ServerAddressByClientCIDR.md)
 - [K8sIoApimachineryPkgApisMetaV1Status](docs/K8sIoApimachineryPkgApisMetaV1Status.md)
 - [K8sIoApimachineryPkgApisMetaV1StatusCause](docs/K8sIoApimachineryPkgApisMetaV1StatusCause.md)
 - [K8sIoApimachineryPkgApisMetaV1StatusDetails](docs/K8sIoApimachineryPkgApisMetaV1StatusDetails.md)
 - [K8sIoApimachineryPkgApisMetaV1Time](docs/K8sIoApimachineryPkgApisMetaV1Time.md)
 - [K8sIoApimachineryPkgApisMetaV1WatchEvent](docs/K8sIoApimachineryPkgApisMetaV1WatchEvent.md)
 - [K8sIoApimachineryPkgRuntimeRawExtension](docs/K8sIoApimachineryPkgRuntimeRawExtension.md)
 - [K8sIoApimachineryPkgUtilIntstrIntOrString](docs/K8sIoApimachineryPkgUtilIntstrIntOrString.md)
 - [V1ACPI](docs/V1ACPI.md)
 - [V1AccessCredential](docs/V1AccessCredential.md)
 - [V1AccessCredentialSecretSource](docs/V1AccessCredentialSecretSource.md)
 - [V1AddVolumeOptions](docs/V1AddVolumeOptions.md)
 - [V1ArchConfiguration](docs/V1ArchConfiguration.md)
 - [V1ArchSpecificConfiguration](docs/V1ArchSpecificConfiguration.md)
 - [V1BIOS](docs/V1BIOS.md)
 - [V1BlockSize](docs/V1BlockSize.md)
 - [V1Bootloader](docs/V1Bootloader.md)
 - [V1CDRomTarget](docs/V1CDRomTarget.md)
 - [V1CPU](docs/V1CPU.md)
 - [V1CPUFeature](docs/V1CPUFeature.md)
 - [V1CPUTopology](docs/V1CPUTopology.md)
 - [V1CertConfig](docs/V1CertConfig.md)
 - [V1ChangedBlockTrackingSelectors](docs/V1ChangedBlockTrackingSelectors.md)
 - [V1ChangedBlockTrackingStatus](docs/V1ChangedBlockTrackingStatus.md)
 - [V1Chassis](docs/V1Chassis.md)
 - [V1ClientPassthroughDevices](docs/V1ClientPassthroughDevices.md)
 - [V1Clock](docs/V1Clock.md)
 - [V1ClockOffset](docs/V1ClockOffset.md)
 - [V1ClockOffsetUTC](docs/V1ClockOffsetUTC.md)
 - [V1CloudInitConfigDriveSource](docs/V1CloudInitConfigDriveSource.md)
 - [V1CloudInitNoCloudSource](docs/V1CloudInitNoCloudSource.md)
 - [V1CommonInstancetypesDeployment](docs/V1CommonInstancetypesDeployment.md)
 - [V1ComponentConfig](docs/V1ComponentConfig.md)
 - [V1ConfigDriveSSHPublicKeyAccessCredentialPropagation](docs/V1ConfigDriveSSHPublicKeyAccessCredentialPropagation.md)
 - [V1ConfigMapVolumeSource](docs/V1ConfigMapVolumeSource.md)
 - [V1ContainerDiskInfo](docs/V1ContainerDiskInfo.md)
 - [V1ContainerDiskSource](docs/V1ContainerDiskSource.md)
 - [V1ControllerRevisionRef](docs/V1ControllerRevisionRef.md)
 - [V1CustomBlockSize](docs/V1CustomBlockSize.md)
 - [V1CustomProfile](docs/V1CustomProfile.md)
 - [V1CustomizeComponents](docs/V1CustomizeComponents.md)
 - [V1CustomizeComponentsPatch](docs/V1CustomizeComponentsPatch.md)
 - [V1DHCPOptions](docs/V1DHCPOptions.md)
 - [V1DHCPPrivateOptions](docs/V1DHCPPrivateOptions.md)
 - [V1DataVolumeSource](docs/V1DataVolumeSource.md)
 - [V1DataVolumeTemplateDummyStatus](docs/V1DataVolumeTemplateDummyStatus.md)
 - [V1DataVolumeTemplateSpec](docs/V1DataVolumeTemplateSpec.md)
 - [V1DeprecatedInterfaceMacvtap](docs/V1DeprecatedInterfaceMacvtap.md)
 - [V1DeprecatedInterfacePasst](docs/V1DeprecatedInterfacePasst.md)
 - [V1DeprecatedInterfaceSlirp](docs/V1DeprecatedInterfaceSlirp.md)
 - [V1DeveloperConfiguration](docs/V1DeveloperConfiguration.md)
 - [V1DeviceAttribute](docs/V1DeviceAttribute.md)
 - [V1DeviceResourceClaimStatus](docs/V1DeviceResourceClaimStatus.md)
 - [V1DeviceStatus](docs/V1DeviceStatus.md)
 - [V1DeviceStatusInfo](docs/V1DeviceStatusInfo.md)
 - [V1Devices](docs/V1Devices.md)
 - [V1Diag288Watchdog](docs/V1Diag288Watchdog.md)
 - [V1DisableFreePageReporting](docs/V1DisableFreePageReporting.md)
 - [V1DisableSerialConsoleLog](docs/V1DisableSerialConsoleLog.md)
 - [V1Disk](docs/V1Disk.md)
 - [V1DiskIOThreads](docs/V1DiskIOThreads.md)
 - [V1DiskTarget](docs/V1DiskTarget.md)
 - [V1DiskVerification](docs/V1DiskVerification.md)
 - [V1DomainMemoryDumpInfo](docs/V1DomainMemoryDumpInfo.md)
 - [V1DomainSpec](docs/V1DomainSpec.md)
 - [V1DownwardAPIVolumeSource](docs/V1DownwardAPIVolumeSource.md)
 - [V1DownwardMetrics](docs/V1DownwardMetrics.md)
 - [V1DownwardMetricsVolumeSource](docs/V1DownwardMetricsVolumeSource.md)
 - [V1EFI](docs/V1EFI.md)
 - [V1EmptyDiskSource](docs/V1EmptyDiskSource.md)
 - [V1EphemeralVolumeSource](docs/V1EphemeralVolumeSource.md)
 - [V1EvacuateCancelOptions](docs/V1EvacuateCancelOptions.md)
 - [V1FeatureAPIC](docs/V1FeatureAPIC.md)
 - [V1FeatureHyperv](docs/V1FeatureHyperv.md)
 - [V1FeatureKVM](docs/V1FeatureKVM.md)
 - [V1FeatureSpinlocks](docs/V1FeatureSpinlocks.md)
 - [V1FeatureState](docs/V1FeatureState.md)
 - [V1FeatureVendorID](docs/V1FeatureVendorID.md)
 - [V1Features](docs/V1Features.md)
 - [V1Filesystem](docs/V1Filesystem.md)
 - [V1FilesystemVirtiofs](docs/V1FilesystemVirtiofs.md)
 - [V1Firmware](docs/V1Firmware.md)
 - [V1Flags](docs/V1Flags.md)
 - [V1FreezeUnfreezeTimeout](docs/V1FreezeUnfreezeTimeout.md)
 - [V1GPU](docs/V1GPU.md)
 - [V1GenerationStatus](docs/V1GenerationStatus.md)
 - [V1GuestAgentCommandInfo](docs/V1GuestAgentCommandInfo.md)
 - [V1GuestAgentPing](docs/V1GuestAgentPing.md)
 - [V1HPETTimer](docs/V1HPETTimer.md)
 - [V1HostDevice](docs/V1HostDevice.md)
 - [V1HostDisk](docs/V1HostDisk.md)
 - [V1HotplugVolumeSource](docs/V1HotplugVolumeSource.md)
 - [V1HotplugVolumeStatus](docs/V1HotplugVolumeStatus.md)
 - [V1Hugepages](docs/V1Hugepages.md)
 - [V1HyperVPassthrough](docs/V1HyperVPassthrough.md)
 - [V1HypervTimer](docs/V1HypervTimer.md)
 - [V1I6300ESBWatchdog](docs/V1I6300ESBWatchdog.md)
 - [V1InitrdInfo](docs/V1InitrdInfo.md)
 - [V1Input](docs/V1Input.md)
 - [V1InstancetypeConfiguration](docs/V1InstancetypeConfiguration.md)
 - [V1InstancetypeMatcher](docs/V1InstancetypeMatcher.md)
 - [V1InstancetypeStatusRef](docs/V1InstancetypeStatusRef.md)
 - [V1Interface](docs/V1Interface.md)
 - [V1InterfaceBindingMigration](docs/V1InterfaceBindingMigration.md)
 - [V1InterfaceBindingPlugin](docs/V1InterfaceBindingPlugin.md)
 - [V1InterfaceBridge](docs/V1InterfaceBridge.md)
 - [V1InterfaceMasquerade](docs/V1InterfaceMasquerade.md)
 - [V1InterfaceSRIOV](docs/V1InterfaceSRIOV.md)
 - [V1KSMConfiguration](docs/V1KSMConfiguration.md)
 - [V1KVMTimer](docs/V1KVMTimer.md)
 - [V1KernelBoot](docs/V1KernelBoot.md)
 - [V1KernelBootContainer](docs/V1KernelBootContainer.md)
 - [V1KernelBootStatus](docs/V1KernelBootStatus.md)
 - [V1KernelInfo](docs/V1KernelInfo.md)
 - [V1KubeVirt](docs/V1KubeVirt.md)
 - [V1KubeVirtCertificateRotateStrategy](docs/V1KubeVirtCertificateRotateStrategy.md)
 - [V1KubeVirtCondition](docs/V1KubeVirtCondition.md)
 - [V1KubeVirtConfiguration](docs/V1KubeVirtConfiguration.md)
 - [V1KubeVirtList](docs/V1KubeVirtList.md)
 - [V1KubeVirtSelfSignConfiguration](docs/V1KubeVirtSelfSignConfiguration.md)
 - [V1KubeVirtSpec](docs/V1KubeVirtSpec.md)
 - [V1KubeVirtStatus](docs/V1KubeVirtStatus.md)
 - [V1KubeVirtWorkloadUpdateStrategy](docs/V1KubeVirtWorkloadUpdateStrategy.md)
 - [V1LaunchSecurity](docs/V1LaunchSecurity.md)
 - [V1LiveUpdateConfiguration](docs/V1LiveUpdateConfiguration.md)
 - [V1LogVerbosity](docs/V1LogVerbosity.md)
 - [V1LunTarget](docs/V1LunTarget.md)
 - [V1Machine](docs/V1Machine.md)
 - [V1MediatedDevicesConfiguration](docs/V1MediatedDevicesConfiguration.md)
 - [V1MediatedHostDevice](docs/V1MediatedHostDevice.md)
 - [V1Memory](docs/V1Memory.md)
 - [V1MemoryDumpVolumeSource](docs/V1MemoryDumpVolumeSource.md)
 - [V1MemoryStatus](docs/V1MemoryStatus.md)
 - [V1MigrateOptions](docs/V1MigrateOptions.md)
 - [V1MigrationConfiguration](docs/V1MigrationConfiguration.md)
 - [V1MultusNetwork](docs/V1MultusNetwork.md)
 - [V1NUMA](docs/V1NUMA.md)
 - [V1NUMAGuestMappingPassthrough](docs/V1NUMAGuestMappingPassthrough.md)
 - [V1Network](docs/V1Network.md)
 - [V1NetworkConfiguration](docs/V1NetworkConfiguration.md)
 - [V1NoCloudSSHPublicKeyAccessCredentialPropagation](docs/V1NoCloudSSHPublicKeyAccessCredentialPropagation.md)
 - [V1NodeMediatedDeviceTypesConfig](docs/V1NodeMediatedDeviceTypesConfig.md)
 - [V1NodePlacement](docs/V1NodePlacement.md)
 - [V1ObjectGraphNode](docs/V1ObjectGraphNode.md)
 - [V1ObjectGraphOptions](docs/V1ObjectGraphOptions.md)
 - [V1PITTimer](docs/V1PITTimer.md)
 - [V1PanicDevice](docs/V1PanicDevice.md)
 - [V1PauseOptions](docs/V1PauseOptions.md)
 - [V1PciHostDevice](docs/V1PciHostDevice.md)
 - [V1PermittedHostDevices](docs/V1PermittedHostDevices.md)
 - [V1PersistentVolumeClaimInfo](docs/V1PersistentVolumeClaimInfo.md)
 - [V1PersistentVolumeClaimVolumeSource](docs/V1PersistentVolumeClaimVolumeSource.md)
 - [V1PluginBinding](docs/V1PluginBinding.md)
 - [V1PodNetwork](docs/V1PodNetwork.md)
 - [V1Port](docs/V1Port.md)
 - [V1PreferenceMatcher](docs/V1PreferenceMatcher.md)
 - [V1Probe](docs/V1Probe.md)
 - [V1QemuGuestAgentSSHPublicKeyAccessCredentialPropagation](docs/V1QemuGuestAgentSSHPublicKeyAccessCredentialPropagation.md)
 - [V1QemuGuestAgentUserPasswordAccessCredentialPropagation](docs/V1QemuGuestAgentUserPasswordAccessCredentialPropagation.md)
 - [V1RESTClientConfiguration](docs/V1RESTClientConfiguration.md)
 - [V1RTCTimer](docs/V1RTCTimer.md)
 - [V1RateLimiter](docs/V1RateLimiter.md)
 - [V1Realtime](docs/V1Realtime.md)
 - [V1ReloadableComponentConfiguration](docs/V1ReloadableComponentConfiguration.md)
 - [V1RemoveVolumeOptions](docs/V1RemoveVolumeOptions.md)
 - [V1ResourceRequirements](docs/V1ResourceRequirements.md)
 - [V1ResourceRequirementsWithoutClaims](docs/V1ResourceRequirementsWithoutClaims.md)
 - [V1RestartOptions](docs/V1RestartOptions.md)
 - [V1Rng](docs/V1Rng.md)
 - [V1SEV](docs/V1SEV.md)
 - [V1SEVAttestation](docs/V1SEVAttestation.md)
 - [V1SEVMeasurementInfo](docs/V1SEVMeasurementInfo.md)
 - [V1SEVPlatformInfo](docs/V1SEVPlatformInfo.md)
 - [V1SEVPolicy](docs/V1SEVPolicy.md)
 - [V1SEVSNP](docs/V1SEVSNP.md)
 - [V1SEVSecretOptions](docs/V1SEVSecretOptions.md)
 - [V1SEVSessionOptions](docs/V1SEVSessionOptions.md)
 - [V1SMBiosConfiguration](docs/V1SMBiosConfiguration.md)
 - [V1SSHPublicKeyAccessCredential](docs/V1SSHPublicKeyAccessCredential.md)
 - [V1SSHPublicKeyAccessCredentialPropagationMethod](docs/V1SSHPublicKeyAccessCredentialPropagationMethod.md)
 - [V1SSHPublicKeyAccessCredentialSource](docs/V1SSHPublicKeyAccessCredentialSource.md)
 - [V1SeccompConfiguration](docs/V1SeccompConfiguration.md)
 - [V1SecretVolumeSource](docs/V1SecretVolumeSource.md)
 - [V1ServiceAccountVolumeSource](docs/V1ServiceAccountVolumeSource.md)
 - [V1SoundDevice](docs/V1SoundDevice.md)
 - [V1StartOptions](docs/V1StartOptions.md)
 - [V1StopOptions](docs/V1StopOptions.md)
 - [V1StorageMigratedVolumeInfo](docs/V1StorageMigratedVolumeInfo.md)
 - [V1SupportContainerResources](docs/V1SupportContainerResources.md)
 - [V1SyNICTimer](docs/V1SyNICTimer.md)
 - [V1SysprepSource](docs/V1SysprepSource.md)
 - [V1TDX](docs/V1TDX.md)
 - [V1TLSConfiguration](docs/V1TLSConfiguration.md)
 - [V1TPMDevice](docs/V1TPMDevice.md)
 - [V1Timer](docs/V1Timer.md)
 - [V1TokenBucketRateLimiter](docs/V1TokenBucketRateLimiter.md)
 - [V1TopologyHints](docs/V1TopologyHints.md)
 - [V1USBHostDevice](docs/V1USBHostDevice.md)
 - [V1USBSelector](docs/V1USBSelector.md)
 - [V1UnpauseOptions](docs/V1UnpauseOptions.md)
 - [V1UserPasswordAccessCredential](docs/V1UserPasswordAccessCredential.md)
 - [V1UserPasswordAccessCredentialPropagationMethod](docs/V1UserPasswordAccessCredentialPropagationMethod.md)
 - [V1UserPasswordAccessCredentialSource](docs/V1UserPasswordAccessCredentialSource.md)
 - [V1VGPUDisplayOptions](docs/V1VGPUDisplayOptions.md)
 - [V1VGPUOptions](docs/V1VGPUOptions.md)
 - [V1VideoDevice](docs/V1VideoDevice.md)
 - [V1VirtualMachine](docs/V1VirtualMachine.md)
 - [V1VirtualMachineCondition](docs/V1VirtualMachineCondition.md)
 - [V1VirtualMachineInstance](docs/V1VirtualMachineInstance.md)
 - [V1VirtualMachineInstanceCondition](docs/V1VirtualMachineInstanceCondition.md)
 - [V1VirtualMachineInstanceFileSystem](docs/V1VirtualMachineInstanceFileSystem.md)
 - [V1VirtualMachineInstanceFileSystemDisk](docs/V1VirtualMachineInstanceFileSystemDisk.md)
 - [V1VirtualMachineInstanceFileSystemInfo](docs/V1VirtualMachineInstanceFileSystemInfo.md)
 - [V1VirtualMachineInstanceFileSystemList](docs/V1VirtualMachineInstanceFileSystemList.md)
 - [V1VirtualMachineInstanceGuestAgentInfo](docs/V1VirtualMachineInstanceGuestAgentInfo.md)
 - [V1VirtualMachineInstanceGuestOSInfo](docs/V1VirtualMachineInstanceGuestOSInfo.md)
 - [V1VirtualMachineInstanceGuestOSUser](docs/V1VirtualMachineInstanceGuestOSUser.md)
 - [V1VirtualMachineInstanceGuestOSUserList](docs/V1VirtualMachineInstanceGuestOSUserList.md)
 - [V1VirtualMachineInstanceList](docs/V1VirtualMachineInstanceList.md)
 - [V1VirtualMachineInstanceMigration](docs/V1VirtualMachineInstanceMigration.md)
 - [V1VirtualMachineInstanceMigrationCondition](docs/V1VirtualMachineInstanceMigrationCondition.md)
 - [V1VirtualMachineInstanceMigrationList](docs/V1VirtualMachineInstanceMigrationList.md)
 - [V1VirtualMachineInstanceMigrationPhaseTransitionTimestamp](docs/V1VirtualMachineInstanceMigrationPhaseTransitionTimestamp.md)
 - [V1VirtualMachineInstanceMigrationSource](docs/V1VirtualMachineInstanceMigrationSource.md)
 - [V1VirtualMachineInstanceMigrationSourceState](docs/V1VirtualMachineInstanceMigrationSourceState.md)
 - [V1VirtualMachineInstanceMigrationSpec](docs/V1VirtualMachineInstanceMigrationSpec.md)
 - [V1VirtualMachineInstanceMigrationState](docs/V1VirtualMachineInstanceMigrationState.md)
 - [V1VirtualMachineInstanceMigrationStatus](docs/V1VirtualMachineInstanceMigrationStatus.md)
 - [V1VirtualMachineInstanceMigrationTarget](docs/V1VirtualMachineInstanceMigrationTarget.md)
 - [V1VirtualMachineInstanceMigrationTargetState](docs/V1VirtualMachineInstanceMigrationTargetState.md)
 - [V1VirtualMachineInstanceNetworkInterface](docs/V1VirtualMachineInstanceNetworkInterface.md)
 - [V1VirtualMachineInstancePhaseTransitionTimestamp](docs/V1VirtualMachineInstancePhaseTransitionTimestamp.md)
 - [V1VirtualMachineInstancePreset](docs/V1VirtualMachineInstancePreset.md)
 - [V1VirtualMachineInstancePresetList](docs/V1VirtualMachineInstancePresetList.md)
 - [V1VirtualMachineInstancePresetSpec](docs/V1VirtualMachineInstancePresetSpec.md)
 - [V1VirtualMachineInstanceProfile](docs/V1VirtualMachineInstanceProfile.md)
 - [V1VirtualMachineInstanceReplicaSet](docs/V1VirtualMachineInstanceReplicaSet.md)
 - [V1VirtualMachineInstanceReplicaSetCondition](docs/V1VirtualMachineInstanceReplicaSetCondition.md)
 - [V1VirtualMachineInstanceReplicaSetList](docs/V1VirtualMachineInstanceReplicaSetList.md)
 - [V1VirtualMachineInstanceReplicaSetSpec](docs/V1VirtualMachineInstanceReplicaSetSpec.md)
 - [V1VirtualMachineInstanceReplicaSetStatus](docs/V1VirtualMachineInstanceReplicaSetStatus.md)
 - [V1VirtualMachineInstanceSpec](docs/V1VirtualMachineInstanceSpec.md)
 - [V1VirtualMachineInstanceStatus](docs/V1VirtualMachineInstanceStatus.md)
 - [V1VirtualMachineInstanceTemplateSpec](docs/V1VirtualMachineInstanceTemplateSpec.md)
 - [V1VirtualMachineList](docs/V1VirtualMachineList.md)
 - [V1VirtualMachineMemoryDumpRequest](docs/V1VirtualMachineMemoryDumpRequest.md)
 - [V1VirtualMachineOptions](docs/V1VirtualMachineOptions.md)
 - [V1VirtualMachineSpec](docs/V1VirtualMachineSpec.md)
 - [V1VirtualMachineStartFailure](docs/V1VirtualMachineStartFailure.md)
 - [V1VirtualMachineStateChangeRequest](docs/V1VirtualMachineStateChangeRequest.md)
 - [V1VirtualMachineStatus](docs/V1VirtualMachineStatus.md)
 - [V1VirtualMachineVolumeRequest](docs/V1VirtualMachineVolumeRequest.md)
 - [V1Volume](docs/V1Volume.md)
 - [V1VolumeMigrationState](docs/V1VolumeMigrationState.md)
 - [V1VolumeSnapshotStatus](docs/V1VolumeSnapshotStatus.md)
 - [V1VolumeStatus](docs/V1VolumeStatus.md)
 - [V1VolumeUpdateState](docs/V1VolumeUpdateState.md)
 - [V1Watchdog](docs/V1Watchdog.md)
 - [V1alpha1MigrationPolicy](docs/V1alpha1MigrationPolicy.md)
 - [V1alpha1MigrationPolicyList](docs/V1alpha1MigrationPolicyList.md)
 - [V1alpha1MigrationPolicySpec](docs/V1alpha1MigrationPolicySpec.md)
 - [V1alpha1MigrationPolicyStatus](docs/V1alpha1MigrationPolicyStatus.md)
 - [V1alpha1Selectors](docs/V1alpha1Selectors.md)
 - [V1beta1CPUInstancetype](docs/V1beta1CPUInstancetype.md)
 - [V1beta1CPUPreferenceRequirement](docs/V1beta1CPUPreferenceRequirement.md)
 - [V1beta1CPUPreferences](docs/V1beta1CPUPreferences.md)
 - [V1beta1ClockPreferences](docs/V1beta1ClockPreferences.md)
 - [V1beta1Condition](docs/V1beta1Condition.md)
 - [V1beta1DataVolumeBlankImage](docs/V1beta1DataVolumeBlankImage.md)
 - [V1beta1DataVolumeCheckpoint](docs/V1beta1DataVolumeCheckpoint.md)
 - [V1beta1DataVolumeSource](docs/V1beta1DataVolumeSource.md)
 - [V1beta1DataVolumeSourceGCS](docs/V1beta1DataVolumeSourceGCS.md)
 - [V1beta1DataVolumeSourceHTTP](docs/V1beta1DataVolumeSourceHTTP.md)
 - [V1beta1DataVolumeSourceImageIO](docs/V1beta1DataVolumeSourceImageIO.md)
 - [V1beta1DataVolumeSourcePVC](docs/V1beta1DataVolumeSourcePVC.md)
 - [V1beta1DataVolumeSourceRef](docs/V1beta1DataVolumeSourceRef.md)
 - [V1beta1DataVolumeSourceRegistry](docs/V1beta1DataVolumeSourceRegistry.md)
 - [V1beta1DataVolumeSourceS3](docs/V1beta1DataVolumeSourceS3.md)
 - [V1beta1DataVolumeSourceSnapshot](docs/V1beta1DataVolumeSourceSnapshot.md)
 - [V1beta1DataVolumeSourceUpload](docs/V1beta1DataVolumeSourceUpload.md)
 - [V1beta1DataVolumeSourceVDDK](docs/V1beta1DataVolumeSourceVDDK.md)
 - [V1beta1DataVolumeSpec](docs/V1beta1DataVolumeSpec.md)
 - [V1beta1DevicePreferences](docs/V1beta1DevicePreferences.md)
 - [V1beta1Error](docs/V1beta1Error.md)
 - [V1beta1FeaturePreferences](docs/V1beta1FeaturePreferences.md)
 - [V1beta1FirmwarePreferences](docs/V1beta1FirmwarePreferences.md)
 - [V1beta1MachinePreferences](docs/V1beta1MachinePreferences.md)
 - [V1beta1MemoryInstancetype](docs/V1beta1MemoryInstancetype.md)
 - [V1beta1MemoryPreferenceRequirement](docs/V1beta1MemoryPreferenceRequirement.md)
 - [V1beta1PersistentVolumeClaim](docs/V1beta1PersistentVolumeClaim.md)
 - [V1beta1PlatformOptions](docs/V1beta1PlatformOptions.md)
 - [V1beta1PreferenceRequirements](docs/V1beta1PreferenceRequirements.md)
 - [V1beta1SnapshotVolumesLists](docs/V1beta1SnapshotVolumesLists.md)
 - [V1beta1SourceIndication](docs/V1beta1SourceIndication.md)
 - [V1beta1SourceSpec](docs/V1beta1SourceSpec.md)
 - [V1beta1SpreadOptions](docs/V1beta1SpreadOptions.md)
 - [V1beta1StorageSpec](docs/V1beta1StorageSpec.md)
 - [V1beta1VirtualMachine](docs/V1beta1VirtualMachine.md)
 - [V1beta1VirtualMachineClone](docs/V1beta1VirtualMachineClone.md)
 - [V1beta1VirtualMachineCloneList](docs/V1beta1VirtualMachineCloneList.md)
 - [V1beta1VirtualMachineCloneSpec](docs/V1beta1VirtualMachineCloneSpec.md)
 - [V1beta1VirtualMachineCloneStatus](docs/V1beta1VirtualMachineCloneStatus.md)
 - [V1beta1VirtualMachineCloneTemplateFilters](docs/V1beta1VirtualMachineCloneTemplateFilters.md)
 - [V1beta1VirtualMachineClusterInstancetype](docs/V1beta1VirtualMachineClusterInstancetype.md)
 - [V1beta1VirtualMachineClusterInstancetypeList](docs/V1beta1VirtualMachineClusterInstancetypeList.md)
 - [V1beta1VirtualMachineClusterPreference](docs/V1beta1VirtualMachineClusterPreference.md)
 - [V1beta1VirtualMachineClusterPreferenceList](docs/V1beta1VirtualMachineClusterPreferenceList.md)
 - [V1beta1VirtualMachineExport](docs/V1beta1VirtualMachineExport.md)
 - [V1beta1VirtualMachineExportLink](docs/V1beta1VirtualMachineExportLink.md)
 - [V1beta1VirtualMachineExportLinks](docs/V1beta1VirtualMachineExportLinks.md)
 - [V1beta1VirtualMachineExportList](docs/V1beta1VirtualMachineExportList.md)
 - [V1beta1VirtualMachineExportManifest](docs/V1beta1VirtualMachineExportManifest.md)
 - [V1beta1VirtualMachineExportSpec](docs/V1beta1VirtualMachineExportSpec.md)
 - [V1beta1VirtualMachineExportStatus](docs/V1beta1VirtualMachineExportStatus.md)
 - [V1beta1VirtualMachineExportVolume](docs/V1beta1VirtualMachineExportVolume.md)
 - [V1beta1VirtualMachineExportVolumeFormat](docs/V1beta1VirtualMachineExportVolumeFormat.md)
 - [V1beta1VirtualMachineInstancetype](docs/V1beta1VirtualMachineInstancetype.md)
 - [V1beta1VirtualMachineInstancetypeList](docs/V1beta1VirtualMachineInstancetypeList.md)
 - [V1beta1VirtualMachineInstancetypeSpec](docs/V1beta1VirtualMachineInstancetypeSpec.md)
 - [V1beta1VirtualMachineOpportunisticUpdateStrategy](docs/V1beta1VirtualMachineOpportunisticUpdateStrategy.md)
 - [V1beta1VirtualMachinePool](docs/V1beta1VirtualMachinePool.md)
 - [V1beta1VirtualMachinePoolAutohealingStrategy](docs/V1beta1VirtualMachinePoolAutohealingStrategy.md)
 - [V1beta1VirtualMachinePoolCondition](docs/V1beta1VirtualMachinePoolCondition.md)
 - [V1beta1VirtualMachinePoolList](docs/V1beta1VirtualMachinePoolList.md)
 - [V1beta1VirtualMachinePoolNameGeneration](docs/V1beta1VirtualMachinePoolNameGeneration.md)
 - [V1beta1VirtualMachinePoolOpportunisticScaleInStrategy](docs/V1beta1VirtualMachinePoolOpportunisticScaleInStrategy.md)
 - [V1beta1VirtualMachinePoolProactiveScaleInStrategy](docs/V1beta1VirtualMachinePoolProactiveScaleInStrategy.md)
 - [V1beta1VirtualMachinePoolProactiveUpdateStrategy](docs/V1beta1VirtualMachinePoolProactiveUpdateStrategy.md)
 - [V1beta1VirtualMachinePoolScaleInStrategy](docs/V1beta1VirtualMachinePoolScaleInStrategy.md)
 - [V1beta1VirtualMachinePoolSelectionPolicy](docs/V1beta1VirtualMachinePoolSelectionPolicy.md)
 - [V1beta1VirtualMachinePoolSelectors](docs/V1beta1VirtualMachinePoolSelectors.md)
 - [V1beta1VirtualMachinePoolSpec](docs/V1beta1VirtualMachinePoolSpec.md)
 - [V1beta1VirtualMachinePoolStatus](docs/V1beta1VirtualMachinePoolStatus.md)
 - [V1beta1VirtualMachinePoolUnmanagedStrategy](docs/V1beta1VirtualMachinePoolUnmanagedStrategy.md)
 - [V1beta1VirtualMachinePoolUpdateStrategy](docs/V1beta1VirtualMachinePoolUpdateStrategy.md)
 - [V1beta1VirtualMachinePreference](docs/V1beta1VirtualMachinePreference.md)
 - [V1beta1VirtualMachinePreferenceList](docs/V1beta1VirtualMachinePreferenceList.md)
 - [V1beta1VirtualMachinePreferenceSpec](docs/V1beta1VirtualMachinePreferenceSpec.md)
 - [V1beta1VirtualMachineRestore](docs/V1beta1VirtualMachineRestore.md)
 - [V1beta1VirtualMachineRestoreList](docs/V1beta1VirtualMachineRestoreList.md)
 - [V1beta1VirtualMachineRestoreSpec](docs/V1beta1VirtualMachineRestoreSpec.md)
 - [V1beta1VirtualMachineRestoreStatus](docs/V1beta1VirtualMachineRestoreStatus.md)
 - [V1beta1VirtualMachineSnapshot](docs/V1beta1VirtualMachineSnapshot.md)
 - [V1beta1VirtualMachineSnapshotContent](docs/V1beta1VirtualMachineSnapshotContent.md)
 - [V1beta1VirtualMachineSnapshotContentList](docs/V1beta1VirtualMachineSnapshotContentList.md)
 - [V1beta1VirtualMachineSnapshotContentSpec](docs/V1beta1VirtualMachineSnapshotContentSpec.md)
 - [V1beta1VirtualMachineSnapshotContentStatus](docs/V1beta1VirtualMachineSnapshotContentStatus.md)
 - [V1beta1VirtualMachineSnapshotList](docs/V1beta1VirtualMachineSnapshotList.md)
 - [V1beta1VirtualMachineSnapshotSpec](docs/V1beta1VirtualMachineSnapshotSpec.md)
 - [V1beta1VirtualMachineSnapshotStatus](docs/V1beta1VirtualMachineSnapshotStatus.md)
 - [V1beta1VirtualMachineTemplateSpec](docs/V1beta1VirtualMachineTemplateSpec.md)
 - [V1beta1VolumeBackup](docs/V1beta1VolumeBackup.md)
 - [V1beta1VolumePreferences](docs/V1beta1VolumePreferences.md)
 - [V1beta1VolumeRestore](docs/V1beta1VolumeRestore.md)
 - [V1beta1VolumeRestoreOverride](docs/V1beta1VolumeRestoreOverride.md)
 - [V1beta1VolumeSnapshotStatus](docs/V1beta1VolumeSnapshotStatus.md)


## Documentation For Authorization


## BearerToken

- **Type**: API key
- **API key parameter name**: authorization
- **Location**: HTTP header


## Author

kubevirt-dev@googlegroups.com

